pub enum AlphabetError {
InvalidId {
value: String,
reason: &'static str,
},
Empty {
id: AlphabetId,
},
DuplicateSymbol {
id: AlphabetId,
first: usize,
duplicate: usize,
},
DuplicateId(AlphabetId),
}Expand description
Failure while defining an alphabet or registering its stable identity.
Variants
InvalidId
An alphabet id was empty or did not use the stable portable syntax.
Empty
A finite musical alphabet contained no symbols.
Fields

id: AlphabetIdStable id of the empty alphabet.
DuplicateSymbol
The same symbol occupied two canonical alphabet positions.
Fields

id: AlphabetIdStable alphabet id.
DuplicateId(AlphabetId)
A registry already contained the stable id being inserted.