SymbolBijectionError

Enum SymbolBijectionError 

pub enum SymbolBijectionError {
    Alphabet(AlphabetError),
    CardinalityMismatch {
        source_cardinality: usize,
        target_cardinality: usize,
    },
    ForeignSourceSymbol {
        alphabet_id: AlphabetId,
    },
    ForeignTargetSymbol {
        alphabet_id: AlphabetId,
    },
    DuplicateSource {
        position: usize,
    },
    DuplicateTarget {
        position: usize,
    },
    MissingSource {
        position: usize,
    },
    MissingTarget {
        position: usize,
    },
    OrdinalMap(OrdinalMapError),
}
Failure while validating a caller-supplied alphabet bijection.

Variants



Alphabet(AlphabetError)

A source or target alphabet was invalid.



CardinalityMismatch

Source and target alphabets had different cardinalities.

Fields

source_cardinality: usize

Source alphabet cardinality.

target_cardinality: usize

Target alphabet or map cardinality.



ForeignSourceSymbol

A supplied source symbol was outside the source alphabet.

Fields

alphabet_id: AlphabetId

Source alphabet identity.



ForeignTargetSymbol

A supplied target symbol was outside the target alphabet.

Fields

alphabet_id: AlphabetId

Target alphabet identity.



DuplicateSource

One source position was declared more than once.

Fields

position: usize

Repeated source position.



DuplicateTarget

Two source symbols selected the same target position.

Fields

position: usize

Repeated target position.



MissingSource

A source position had no mapping.

Fields

position: usize

Unmapped source position.



MissingTarget

A target position had no preimage.

Fields

position: usize

Unmapped target position.



OrdinalMap(OrdinalMapError)

The internal ordinal spelling was not a bijection.