TransformCertificate

Struct TransformCertificate 

pub struct TransformCertificate<A: SerialAlphabet> {
    pub source_alphabet: AlphabetId,
    pub target_alphabet: AlphabetId,
    pub aggregate_preserved: bool,
    pub order_map: OrdinalMap,
    pub inverse: Option<SeriesTransform<A>>,
    pub relaxed_invariants: Vec<RelaxedInvariant>,
}
Algebra evidence for one successfully applied transform.

Fields

source_alphabet: AlphabetId

Stable identity of the validated source alphabet.

target_alphabet: AlphabetId

Stable identity of the validated target alphabet.

aggregate_preserved: bool

Whether aggregate policy and counts were preserved under the bijections.

order_map: OrdinalMap

Exact output-position to source-position map used by the transform.

inverse: Option<SeriesTransform<A>>

Exact inverse operation when the transform algebra supplies one.

relaxed_invariants: Vec<RelaxedInvariant>

Source invariants intentionally relaxed by this operation.